﻿using System;
using ThinkGeo.MapSuite.Core;

namespace CustomZoomLevelSet
{
    public partial class _Default : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                string version = ThinkGeo.MapSuite.WebEdition.Map.Version;  // "MapSuiteCore:3.1.182;WebEdition:3.1.182"
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-131.22, 55.05, -54.03, 16.91);
                Map1.MapUnit = GeographyUnit.DecimalDegree;

                ShapeFileFeatureLayer USLayer = new ShapeFileFeatureLayer(MapPath("~/App_Data/states.shp"));
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GeAreatZoomLevel(199998.5, GeoColor.SimpleColors.Red));
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GeAreatZoomLevel(1.5, GeoColor.SimpleColors.Yellow));
                USLayer.ZoomLevelSet.CustomZoomLevels.Add(GeAreatZoomLevel(0.5, GeoColor.SimpleColors.Green));

                ShapeFileFeatureLayer citiesLayer = new ShapeFileFeatureLayer(MapPath("~/App_Data/cities_a.shp"));
                citiesLayer.ZoomLevelSet.CustomZoomLevels.Add(GePointZoomLevel(98500, GeoColor.SimpleColors.Black));
                citiesLayer.ZoomLevelSet.CustomZoomLevels.Add(GePointZoomLevel(1500, GeoColor.SimpleColors.Green));
                citiesLayer.ZoomLevelSet.CustomZoomLevels.Add(GePointZoomLevel(500, GeoColor.SimpleColors.Red));

                Map1.StaticOverlay.Layers.Add(USLayer);
                Map1.StaticOverlay.Layers.Add(citiesLayer);

                Map1.SyncClientZoomLevels(GetCustomZoomLevelSet());
            }
        }

        private ZoomLevelSet GetCustomZoomLevelSet()
        {
            ZoomLevelSet zoomLevelSet = new ZoomLevelSet();
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(62500000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(15625000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(3906250));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(1500000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(750000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(200000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(110000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(100000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(90000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(51000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(50000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(49000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(10000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(1100));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(1000));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(900));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(100));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(10));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(1.5));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(1));
            zoomLevelSet.CustomZoomLevels.Add(new ZoomLevel(0.5));
            return zoomLevelSet;
        }

        private ZoomLevel GeAreatZoomLevel(double scale, GeoColor geoColor)
        {
            ZoomLevel zoomLevel = new ZoomLevel(scale);
            zoomLevel.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(geoColor);
            return zoomLevel;
        }

        private ZoomLevel GePointZoomLevel(double scale, GeoColor geoColor)
        {
            ZoomLevel zoomLevel = new ZoomLevel(scale);
            zoomLevel.DefaultPointStyle = PointStyles.CreateSimpleCircleStyle(geoColor, 8f);
            return zoomLevel;
        }

        protected void Map1_ExtentChanged(object sender, ThinkGeo.MapSuite.WebEdition.ExtentChangedEventArgs e)
        {
            string currentScale = e.CurrentScale.ToString("n4");
            divExtent.InnerHtml = currentScale;
        }
    }
}
